pub struct DataComponent {
pub common: CommonProperties,
pub name: String,
pub description: Option<String>,
pub data_source_ref: Option<String>,
pub version: Option<String>,
pub domains: Vec<String>,
}Expand description
Represents a MITRE ATT&CK Data Component (x-mitre-data-component).
Data Components are specific properties or values of a Data Source that can be used to detect adversary behavior. For example, the “Process” data source has components like “Process Creation”, “Process Termination”, etc.
Fields
common: CommonPropertiesname: Stringdescription: Option<String>data_source_ref: Option<String>Reference to parent Data Source
version: Option<String>domains: Vec<String>Trait Implementations
Sourceimpl AttackObject for DataComponent
impl AttackObject for DataComponent
Sourceimpl Clone for DataComponent
impl Clone for DataComponent
Sourcefn clone(&self) -> DataComponent
fn clone(&self) -> DataComponent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataComponent
impl Debug for DataComponent
Sourceimpl<'de> Deserialize<'de> for DataComponent
impl<'de> Deserialize<'de> for DataComponent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DataComponent
impl PartialEq for DataComponent
Sourceimpl Serialize for DataComponent
impl Serialize for DataComponent
Sourceimpl StixObject for DataComponent
impl StixObject for DataComponent
impl Eq for DataComponent
impl StructuralPartialEq for DataComponent